#
# spec file for package perl-MooseX-App
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-MooseX-App
Version:        1.39
Release:        1.1
%define cpan_name MooseX-App
Summary:        Write user-friendly command line apps with even less suffering
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/MooseX-App/
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MAROS/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Config::Any)
BuildRequires:  perl(List::Util) >= 1.44
BuildRequires:  perl(Module::Pluggable)
BuildRequires:  perl(Moose) >= 2.00
BuildRequires:  perl(MooseX::Types::Path::Class)
BuildRequires:  perl(Path::Class)
BuildRequires:  perl(Pod::Elemental)
BuildRequires:  perl(Test::Most)
BuildRequires:  perl(Test::NoWarnings)
BuildRequires:  perl(namespace::autoclean)
Requires:       perl(Config::Any)
Requires:       perl(List::Util) >= 1.44
Requires:       perl(Module::Pluggable)
Requires:       perl(Moose) >= 2.00
Requires:       perl(MooseX::Types::Path::Class)
Requires:       perl(Path::Class)
Requires:       perl(Pod::Elemental)
Requires:       perl(namespace::autoclean)
Recommends:     perl(File::HomeDir)
Recommends:     perl(IO::Interactive)
Recommends:     perl(Term::ReadKey)
Recommends:     perl(Text::WagnerFischer)
%{perl_requires}

%description
MooseX-App is a highly customisable helper to write user-friendly command
line applications without having to worry about most of the annoying things
usually involved. Just take any existing Moose class, add a single line
('use MooseX-App qw(PluginA PluginB ...);') and create one class for each
command in an underlying namespace. Options and positional parameters can
be defined as simple Moose accessors using the 'option' and 'parameter'
keywords respectively.

MooseX-App will then

* * Find, load and initialise the command classes (see
  MooseX::App::Simple for single class/command applications)

* * Create automated help and documentation from modules POD as well as
  attributes metadata and type constraints

* * Read, encode and validate the command line options and positional
  parameters entered by the user from @ARGV and %ENV (and possibly prompt
  the user for additional parameters see MooseX::App::Plugin::Term)

* * Provide helpful error messages if user input cannot be validated
  (either missing or wrong attributes or Moose type constraints not
  satisfied)
  or if the user requests help.

Commandline options are defined using the 'option' keyword which accepts
the same attributes as Moose' 'has' keyword.

  option 'some_option' => (
      is            => 'rw',
      isa           => 'Str',
  );

This is equivalent to

  has 'some_option' => (
      is            => 'rw',
      isa           => 'Str',
      traits        => ['AppOption'],   # Load extra metaclass
      cmd_type      => 'option',        # Set attribute type
  );

Single letter options are treated as flags and may be combined with
eachother. However such options must have a Boolean type constraint.

 option 'verbose' => (
      is            => 'rw',
      isa           => 'Bool',
      cmd_flag      => 'v',
  );

Positional parameters are defined with the 'parameter' keyword

  parameter 'some_option' => (
      is            => 'rw',
      isa           => 'Str',
  );

This is equivalent to

  has 'some_option' => (
      is            => 'rw',
      isa           => 'Str',
      traits        => ['AppOption'],
      cmd_type      => 'parameter',
  );

All keywords are imported by Moosex::App (in the app base class) and
MooseX::App::Command (in the command class) or MooseX::App::Simple (single
class application).

Furthermore, all options and parameters can also be supplied via %ENV

  option 'some_option' => (
      is            => 'rw',
      isa           => 'Str',
      cmd_env       => 'SOME_OPTION', # sets the env key
  );

Moose type constraints help MooseX::App to construct helpful error messages
and parse @ARGV in a meaningful way. The following type constraints are
supported:

* * ArrayRef: Specify multiple values ('--opt value1 --opt value2',
  also see app_permute and cmd_split)

* * HashRef: Specify multiple key value pairs ('--opt key=value --opt
  key2=value2', also see app_permute)

* * Enum: Display all possibilities

* * Bool: Flags that do not require values

* * Int, Num: Used for proper error messages

Read the Tutorial for getting started with a simple MooseX::App command
line application.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes LICENCE README TODO

%changelog
* Mon Sep 25 2017 coolo@suse.com
- updated to 1.39
  see /usr/share/doc/packages/perl-MooseX-App/Changes
* Thu May 25 2017 coolo@suse.com
- updated to 1.38
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.38 2017-06-20
  - Cleanups (get rid of smartmatch, inentation, documentation, tests)
  - Also handle =head[2-4] tags when processing pod (#47)
  - Subcommands (based on work by Yanick Champoux)
* Wed Feb 22 2017 coolo@suse.com
- updated to 1.3701
  see /usr/share/doc/packages/perl-MooseX-App/Changes
* Mon Nov 14 2016 coolo@suse.com
- updated to 1.37
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.37 2016-11-13
  - Refactor the way values are parsed from @ARGV
  - Rework boolean negation
  - Add developer checks
* Wed Oct 12 2016 coolo@suse.com
- updated to 1.36
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.36 2016-10-11
  - Documentation
  - Set correct encoding on STDERR
  - Fix order of options (fixed by J.R. Mash)
  - Replace dashes in variable names with underscores in bash completion (implemented by Tina Müller)
  - Do not autocomplete autocomplete itself (implemented by Lisa Hare)
  - Create correct documentation for options with cmd_split
  - Rename hints key to clarify purpose
  - Add ability to negate boolean options (implemented by Marc Logghe)
  - Spelling fixes github#39 (fixed by Gregor Herrmann)
  - Retain original order of elements from @ARGV
* Mon Apr  4 2016 coolo@suse.com
- updated to 1.35
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.35 2016-04-02
  - Apply Spelling fixes RT112234 (fixed by Gregor Herrmann)
  - Documentation
  - Allow to pass ARGV directly to constructor
  - use namespace::autoclean (reported by Mohammad S Anwar)
  - Dist housekeeping
* Tue Mar  8 2016 coolo@suse.com
- updated to 1.34
  see /usr/share/doc/packages/perl-MooseX-App/Changes
  1.34 2016-02-21
  - Do not accept invalid character in Term plugin
  - Fix RT112156: Command class lacking attribute metarole (reported by Marc Logghe)
  - Apply Spelling fixes RT105717 (fixed by Gregor Herrmann)
  - Add permute option to specify multiple values with one attribute key
  - Fix imports (fixed by Alexander Stoddard)
  - Documentation
* Sun Apr 19 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
